# Config file for the magics package
# Defines the following variables:
#
#  MAGICS_INCLUDE_DIRS - include directories
#  MAGICS_DEFINITIONS  - preprocessor definitions
#  MAGICS_LIBRARIES    - libraries to link against
#  MAGICS_FEATURES     - list of enabled features
#  MAGICS_VERSION      - version of the package
#
# Also defines magics third-party library dependencies:
#  MAGICS_TPLS             - package names of  third-party library dependencies
#  MAGICS_TPL_INCLUDE_DIRS - include directories
#  MAGICS_TPL_DEFINITIONS  - preprocessor definitions
#  MAGICS_TPL_LIBRARIES    - libraries to link against

### compute paths

get_filename_component(MAGICS_CMAKE_DIR "${CMAKE_CURRENT_LIST_FILE}" PATH)

set( MAGICS_SELF_INCLUDE_DIRS "/usr/include/magics" )
set( MAGICS_SELF_DEFINITIONS  "_FILE_OFFSET_BITS=64" )
set( MAGICS_SELF_LIBRARIES    "MagPlus" )

set( MAGICS_TPLS              "grib_api;spot;odb_api;EXPAT;NetCDF;PangoCairo;Proj4;EMOS" )
set( MAGICS_TPL_INCLUDE_DIRS  "/usr/include;/usr/include;/usr/include/hdf5/serial;/usr/include/pango-1.0;/usr/include/cairo;/usr/include/glib-2.0;/usr/lib/arm-linux-gnueabihf/glib-2.0/include;/usr/include/pixman-1;/usr/include/freetype2;/usr/include/libpng12;/usr/include" )
set( MAGICS_TPL_DEFINITIONS   "" )
set( MAGICS_TPL_LIBRARIES     "/usr/lib/arm-linux-gnueabihf/libexpat.so;debug;optimized;/usr/lib/arm-linux-gnueabihf/libnetcdf.so;/usr/lib/arm-linux-gnueabihf/libnetcdf_c++.so;/usr/lib/arm-linux-gnueabihf/hdf5/serial/lib/libhdf5.so;/usr/lib/arm-linux-gnueabihf/libpthread.so;/usr/lib/arm-linux-gnueabihf/libz.so;/usr/lib/arm-linux-gnueabihf/libdl.so;/usr/lib/arm-linux-gnueabihf/libm.so;pangocairo-1.0;pango-1.0;gobject-2.0;glib-2.0;cairo;/usr/lib/arm-linux-gnueabihf/libproj.so;/usr/lib/arm-linux-gnueabihf/libemos.R64.D64.I32.so;/usr/lib/gcc/arm-linux-gnueabihf/5/libgfortran.so" )

### export include paths as absolute paths

set( MAGICS_INCLUDE_DIRS "" )
foreach( path ${MAGICS_SELF_INCLUDE_DIRS} )
	get_filename_component( abspath ${path} ABSOLUTE )
	list( APPEND MAGICS_INCLUDE_DIRS ${abspath} )
endforeach()
list( APPEND MAGICS_INCLUDE_DIRS ${MAGICS_TPL_INCLUDE_DIRS} )

### export definitions

set( MAGICS_DEFINITIONS      ${MAGICS_SELF_DEFINITIONS} ${MAGICS_TPL_DEFINITIONS} )

### export list of all libraries

set( MAGICS_LIBRARIES        ${MAGICS_SELF_LIBRARIES}   ${MAGICS_TPL_LIBRARIES}   )

### export the features provided by the package

set( MAGICS_FEATURES    "" )
foreach( _f ${MAGICS_FEATURES} )
	set( ${_f} 1 )
endforeach()

if( EXISTS ${MAGICS_CMAKE_DIR}/magics-import.cmake )
  set( MAGICS_IMPORT_FILE "${MAGICS_CMAKE_DIR}/magics-import.cmake" )
  include( ${MAGICS_IMPORT_FILE} )
endif()

# insert definitions for IMPORTED targets

if( NOT magics_BINARY_DIR )

		include( "${MAGICS_CMAKE_DIR}/magics-targets.cmake" )

endif()

# here goes the imports of the TPL's

include( ${CMAKE_CURRENT_LIST_FILE}.tpls OPTIONAL )

# publish this file as imported

set( MAGICS_IMPORT_FILE ${CMAKE_CURRENT_LIST_FILE} )
mark_as_advanced( MAGICS_IMPORT_FILE )

